Example Scripts — MoviePy 1.0.1 documentation

# Example Scripts

Here are a few example scripts to get you started. Most are quite old now and will be soon replaced.

- Text with moving letters
- A reconstitution of 15th century dancing
- A simple music video
- An example with sound
- A Star-Wars like opening title
- Partially Hidden credits
- Freezing a movie frame with a painting effect
- Placing clips according to a picture
- MoviePy logo with a moving shadow
- Tracking and blurring someone’s face
- Quick recipes
- Character duplication in a video
- “The End” effect